@@ -22,8 +22,6 @@
  *
  */
 
-#include "config.h"
-
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
@@ -32,7 +30,6 @@
 #include <glib-object.h>
 
 #include <telepathy-glib/telepathy-glib.h>
-#include <telepathy-glib/telepathy-glib-dbus.h>
 
 static gchar *app_name;
 static GMainLoop *main_loop;
@@ -46,7 +43,6 @@ show_help (gchar * err)
     printf ("Usage:\n"
 	    "    %1$s list\n"
 	    "    %1$s summary\n"
-	    "    %1$s dump\n"
 	    "    %1$s add <manager>/<protocol> <display name> [<param> ...]\n"
 	    "    %1$s update <account name> [<param>|clear:key] ...\n"
 	    "    %1$s display <account name> <display name>\n"
@@ -324,7 +320,10 @@ show_uri_schemes (const gchar * const *schemes)
   int result;
   gchar *tmp;
 
-  tmp = g_strjoinv (", ", (gchar **) schemes);
+  if (schemes == NULL || schemes[0] == NULL)
+    tmp = g_strdup ("");
+  else
+    tmp = g_strjoinv (", ", (gchar **) schemes);
 
   result = printf ("%12s: %s\n", "URIScheme", tmp);
 
@@ -425,7 +424,6 @@ typedef enum {
     GET_PARAM,
     GET_STRING,
     GET_BOOLEAN,
-    GET_PRESENCE,
     GET_PRESENCE_TYPE,
     GET_PRESENCE_STATUS,
     GET_PRESENCE_MESSAGE
@@ -475,8 +473,6 @@ getter_list_init(void)
 		    tp_account_get_connect_automatically);
     getter_list_add("NormalizedName", GET_STRING, tp_account_get_normalized_name);
 
-    getter_list_add("AutomaticPresence",
-                    GET_PRESENCE, tp_account_get_automatic_presence);
     getter_list_add("AutomaticPresenceType",
 		    GET_PRESENCE_TYPE, tp_account_get_automatic_presence);
     getter_list_add("AutomaticPresenceStatus",
@@ -518,16 +514,16 @@ compare_accounts (gconstpointer a,
 }
 
 static GList *
-dup_valid_accounts_sorted (TpAccountManager *manager)
+get_valid_accounts_sorted (TpAccountManager *manager)
 {
-    return g_list_sort (tp_account_manager_dup_valid_accounts (manager),
+    return g_list_sort (tp_account_manager_get_valid_accounts (manager),
                         compare_accounts);
 }
 
 static gboolean
 command_list (TpAccountManager *manager)
 {
-    GList *accounts = dup_valid_accounts_sorted (manager);
+    GList *accounts = get_valid_accounts_sorted (manager);
 
     if (accounts != NULL) {
 	GList *ptr;
@@ -538,7 +534,7 @@ command_list (TpAccountManager *manager)
 	    puts (tp_account_get_path_suffix (ptr->data));
 	}
 
-	g_list_free_full (accounts, g_object_unref);
+	g_list_free (accounts);
     }
 
     return FALSE;                 /* stop mainloop */
@@ -550,7 +546,7 @@ command_summary (TpAccountManager *manager)
     GList *accounts, *l;
     guint longest_account = 0;
 
-    accounts = tp_account_manager_dup_valid_accounts (manager);
+    accounts = tp_account_manager_get_valid_accounts (manager);
     if (accounts == NULL) {
         return FALSE;
     }
@@ -583,7 +579,7 @@ command_summary (TpAccountManager *manager)
             status);
     }
 
-    g_list_free_full (accounts, g_object_unref);
+    g_list_free (accounts);
     return FALSE; /* stop mainloop */
 }
 
@@ -686,36 +682,6 @@ command_remove (TpAccount *account)
     return TRUE;
 }
 
-static gchar *
-dup_storage_restrictions (TpAccount *account)
-{
-  TpStorageRestrictionFlags flags;
-  GPtrArray *tmp;
-  gchar *result;
-
-  flags = tp_account_get_storage_restrictions (account);
-  if (flags == 0)
-    return g_strdup ("(none)");
-
-  tmp = g_ptr_array_new ();
-
-  if (flags & TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_PARAMETERS)
-    g_ptr_array_add (tmp, "Cannot_Set_Parameters");
-  if (flags & TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_ENABLED)
-    g_ptr_array_add (tmp, "Cannot_Set_Enabled");
-  if (flags & TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_PRESENCE)
-    g_ptr_array_add (tmp, "Cannot_Set_Presence");
-  if (flags & TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_SERVICE)
-    g_ptr_array_add (tmp, "Cannot_Set_Service");
-
-  g_ptr_array_add (tmp, NULL);
-
-  result = g_strjoinv (", ", (gchar **) tmp->pdata);
-
-  g_ptr_array_unref (tmp);
-  return result;
-}
-
 static gboolean
 command_show (TpAccount *account)
 {
@@ -724,8 +690,6 @@ command_show (TpAccount *account)
     gpointer keyp, valuep;
     struct presence automatic, current, requested;
     const gchar * const *schemes;
-    const gchar *storage_provider;
-    const gchar * const *supersedes;
 
     show ("Account", tp_account_get_path_suffix (account));
     show ("Display Name", tp_account_get_display_name (account));
@@ -762,50 +726,10 @@ command_show (TpAccount *account)
     show ("Changing",
         tp_account_get_changing_presence (account) ? "yes" : "no");
 
+    puts ("");
+    puts ("Addressing:");
     schemes = tp_account_get_uri_schemes (account);
-    if (schemes != NULL && schemes[0] != NULL)
-      {
-        puts ("");
-        puts ("Addressing:");
-
-        show_uri_schemes (schemes);
-      }
-
-    storage_provider = tp_account_get_storage_provider (account);
-    if (!tp_str_empty (storage_provider))
-      {
-        GVariant *storage_identifier;
-        gchar *storage_restrictions;
-
-        puts ("");
-        puts ("Storage:");
-        show ("Provider", storage_provider);
-
-        storage_identifier = tp_account_dup_storage_identifier_variant (
-            account);
-        if (storage_identifier != NULL)
-          {
-            gchar *tmp = g_variant_print (storage_identifier, TRUE);
-
-            show ("Identifier", tmp);
-
-            g_free (tmp);
-            g_variant_unref (storage_identifier);
-          }
-
-        storage_restrictions = dup_storage_restrictions (account);
-        show ("Restrictions", storage_restrictions);
-        g_free (storage_restrictions);
-      }
-
-    supersedes = tp_account_get_supersedes (account);
-    if (supersedes != NULL && supersedes[0] != NULL)
-      {
-        puts ("");
-        puts ("Supersedes:");
-        for (; *supersedes != NULL; supersedes++)
-          printf ("  %s\n", *supersedes + strlen (TP_ACCOUNT_OBJECT_PATH_BASE));
-      }
+    show_uri_schemes (schemes);
 
     puts ("");
     parameters = tp_account_get_parameters (account);
@@ -820,30 +744,6 @@ command_show (TpAccount *account)
     return FALSE;
 }
 
-static gboolean
-command_dump (TpAccountManager *manager)
-{
-    GList *accounts, *l;
-
-    accounts = tp_account_manager_dup_valid_accounts (manager);
-    if (accounts == NULL) {
-        return FALSE;
-    }
-    command.common.ret = 0;
-
-    for (l = accounts; l != NULL; l = l->next) {
-        TpAccount *account = TP_ACCOUNT (l->data);
-
-        command_show (account);
-
-        if (l->next != NULL)
-          printf ("\n------------------------------------------------------------\n\n");
-    }
-
-    g_list_free_full (accounts, g_object_unref);
-    return FALSE; /* stop mainloop */
-}
-
 static gboolean
 command_connection (TpAccount *account)
 {
@@ -897,16 +797,6 @@ command_get (TpAccount *account)
 	    else if (getter->type == GET_BOOLEAN) {
 		puts(getboolean(account) ? "true" : "false");
 	    }
-            else if (getter->type == GET_PRESENCE)
-            {
-                struct presence presence;
-
-                presence.type = getpresence(account, &presence.status,
-                    &presence.message);
-                printf ("(%u, \"%s\", \"%s\")\n", presence.type,
-                    presence.status, presence.message);
-                free_presence (&presence);
-            }
 	    else if (getter->type == GET_PRESENCE_TYPE ||
 		     getter->type == GET_PRESENCE_STATUS ||
 		     getter->type == GET_PRESENCE_MESSAGE) {
@@ -1051,7 +941,7 @@ command_auto_presence (TpAccount *account)
                                              command.presence.status,
                                              command.presence.message,
                                              callback_for_async,
-                                             tp_account_set_automatic_presence_finish);
+                                             tp_account_request_presence_finish);
 
     return TRUE;
 }
@@ -1138,14 +1028,6 @@ parse (int argc, char **argv)
 
         command.ready.manager = command_summary;
     }
-    else if (strcmp (argv[1], "dump") == 0)
-    {
-        /* Dump all accounts */
-        if (argc != 2)
-            show_help ("Invalid dump command.");
-
-        command.ready.manager = command_dump;
-    }
     else if (strcmp  (argv[1], "remove") == 0
 	     || strcmp (argv[1], "delete") == 0)
     {
@@ -1423,10 +1305,7 @@ main (int argc, char **argv)
     TpAccountManager *am = NULL;
     TpAccount *a = NULL;
     TpDBusDaemon *dbus = NULL;
-    TpSimpleClientFactory *client_factory = NULL;
     GError *error = NULL;
-    const GQuark features[] = { TP_ACCOUNT_FEATURE_CORE,
-        TP_ACCOUNT_FEATURE_ADDRESSING, TP_ACCOUNT_FEATURE_STORAGE, 0 };
 
     g_type_init ();
 
@@ -1442,23 +1321,16 @@ main (int argc, char **argv)
             app_name, command.common.name, error->message);
         goto out;
     }
-    client_factory = tp_simple_client_factory_new (dbus);
 
     if (command.common.account == NULL) {
-        TpSimpleClientFactory *factory;
-
         am = tp_account_manager_new (dbus);
-        factory = tp_proxy_get_factory (am);
-
-        tp_simple_client_factory_add_account_features (factory, features);
-
         tp_proxy_prepare_async (am, NULL, manager_ready, NULL);
     }
     else {
+	const GQuark features[] = { TP_ACCOUNT_FEATURE_CORE, TP_ACCOUNT_FEATURE_ADDRESSING, 0 };
 
 	command.common.account = ensure_prefix (command.common.account);
-        a = tp_simple_client_factory_ensure_account (client_factory,
-            command.common.account, NULL, &error);
+	a = tp_account_new (dbus, command.common.account, &error);
 
 	if (error != NULL)
 	{
@@ -1476,7 +1348,6 @@ main (int argc, char **argv)
 
 out:
     g_clear_error (&error);
-    tp_clear_object (&client_factory);
     tp_clear_object (&dbus);
     tp_clear_object (&am);
     tp_clear_object (&a);
